# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from chat_server_connector.models.chat_session_get_with_chat_data import ChatSessionGetWithChatData
from chat_server_connector.models.feedback_type import FeedbackType

class FeedbackWithSessionRead(BaseModel):
    """
    FeedbackWithSessionRead
    """
    id: StrictInt = Field(...)
    chat_session_id: StrictInt = Field(...)
    chat_member_id: StrictInt = Field(...)
    type: FeedbackType = Field(...)
    text: Optional[StrictStr] = None
    priority: StrictInt = Field(...)
    added_at: StrictInt = Field(...)
    updated_at: StrictInt = Field(...)
    chat_session: ChatSessionGetWithChatData = Field(...)
    __properties = ["id", "chat_session_id", "chat_member_id", "type", "text", "priority", "added_at", "updated_at", "chat_session"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FeedbackWithSessionRead:
        """Create an instance of FeedbackWithSessionRead from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of chat_session
        if self.chat_session:
            _dict['chat_session'] = self.chat_session.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FeedbackWithSessionRead:
        """Create an instance of FeedbackWithSessionRead from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FeedbackWithSessionRead.parse_obj(obj)

        _obj = FeedbackWithSessionRead.parse_obj({
            "id": obj.get("id"),
            "chat_session_id": obj.get("chat_session_id"),
            "chat_member_id": obj.get("chat_member_id"),
            "type": obj.get("type"),
            "text": obj.get("text"),
            "priority": obj.get("priority"),
            "added_at": obj.get("added_at"),
            "updated_at": obj.get("updated_at"),
            "chat_session": ChatSessionGetWithChatData.from_dict(obj.get("chat_session")) if obj.get("chat_session") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from chat_server_connector.models.ai_assistant_goal_get import AiAssistantGoalGet
from chat_server_connector.models.ai_assistant_lexicon_item import AiAssistantLexiconItem
from chat_server_connector.models.assistant_function import AssistantFunction
from chat_server_connector.models.assistant_type import AssistantType
from chat_server_connector.models.conversation_style import ConversationStyle
from chat_server_connector.models.knowledgebase_state import KnowledgebaseState

class AiAssistantGet(BaseModel):
    """
    AiAssistantGet  # noqa: E501
    """
    allow_text: StrictBool = Field(...)
    allow_voice: StrictBool = Field(...)
    approved_urls: conlist(StrictStr) = Field(...)
    avatar_id: Optional[StrictStr] = None
    banned_keywords: conlist(StrictStr) = Field(...)
    conversation_starter: Optional[StrictStr] = None
    conversation_style: ConversationStyle = Field(...)
    created_at: StrictInt = Field(...)
    deleted_at: Optional[StrictInt] = None
    function: AssistantFunction = Field(...)
    goals: Optional[conlist(AiAssistantGoalGet)] = None
    id: StrictInt = Field(...)
    is_active: StrictBool = Field(...)
    is_available: Optional[StrictBool] = False
    is_live: StrictBool = Field(...)
    knowledgebase_state: Optional[KnowledgebaseState] = None
    last_updated_at: StrictInt = Field(...)
    lexicon_items: Optional[conlist(AiAssistantLexiconItem)] = None
    name: StrictStr = Field(...)
    prefer_voice: StrictBool = Field(...)
    system_prompt: Optional[StrictStr] = None
    system_prompt_support: Optional[StrictStr] = None
    system_prompt_tutor: Optional[StrictStr] = None
    type: AssistantType = Field(...)
    voice_id: StrictInt = Field(...)
    __properties = ["allow_text", "allow_voice", "approved_urls", "avatar_id", "banned_keywords", "conversation_starter", "conversation_style", "created_at", "deleted_at", "function", "goals", "id", "is_active", "is_available", "is_live", "knowledgebase_state", "last_updated_at", "lexicon_items", "name", "prefer_voice", "system_prompt", "system_prompt_support", "system_prompt_tutor", "type", "voice_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AiAssistantGet:
        """Create an instance of AiAssistantGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in goals (list)
        _items = []
        if self.goals:
            for _item in self.goals:
                if _item:
                    _items.append(_item.to_dict())
            _dict['goals'] = _items
        # override the default output from pydantic by calling `to_dict()` of knowledgebase_state
        if self.knowledgebase_state:
            _dict['knowledgebase_state'] = self.knowledgebase_state.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in lexicon_items (list)
        _items = []
        if self.lexicon_items:
            for _item in self.lexicon_items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['lexicon_items'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AiAssistantGet:
        """Create an instance of AiAssistantGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AiAssistantGet.parse_obj(obj)

        _obj = AiAssistantGet.parse_obj({
            "allow_text": obj.get("allow_text"),
            "allow_voice": obj.get("allow_voice"),
            "approved_urls": obj.get("approved_urls"),
            "avatar_id": obj.get("avatar_id"),
            "banned_keywords": obj.get("banned_keywords"),
            "conversation_starter": obj.get("conversation_starter"),
            "conversation_style": obj.get("conversation_style"),
            "created_at": obj.get("created_at"),
            "deleted_at": obj.get("deleted_at"),
            "function": obj.get("function"),
            "goals": [AiAssistantGoalGet.from_dict(_item) for _item in obj.get("goals")] if obj.get("goals") is not None else None,
            "id": obj.get("id"),
            "is_active": obj.get("is_active"),
            "is_available": obj.get("is_available") if obj.get("is_available") is not None else False,
            "is_live": obj.get("is_live"),
            "knowledgebase_state": KnowledgebaseState.from_dict(obj.get("knowledgebase_state")) if obj.get("knowledgebase_state") is not None else None,
            "last_updated_at": obj.get("last_updated_at"),
            "lexicon_items": [AiAssistantLexiconItem.from_dict(_item) for _item in obj.get("lexicon_items")] if obj.get("lexicon_items") is not None else None,
            "name": obj.get("name"),
            "prefer_voice": obj.get("prefer_voice"),
            "system_prompt": obj.get("system_prompt"),
            "system_prompt_support": obj.get("system_prompt_support"),
            "system_prompt_tutor": obj.get("system_prompt_tutor"),
            "type": obj.get("type"),
            "voice_id": obj.get("voice_id")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.chat_message_read_with_metadata import ChatMessageReadWithMetadata  # noqa: E501

class TestChatMessageReadWithMetadata(unittest.TestCase):
    """ChatMessageReadWithMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatMessageReadWithMetadata:
        """Test ChatMessageReadWithMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatMessageReadWithMetadata`
        """
        model = ChatMessageReadWithMetadata()  # noqa: E501
        if include_optional:
            return ChatMessageReadWithMetadata(
                text = '',
                file_id = '',
                id = 56,
                chat_message_type = 'TEXT',
                run_id = '',
                chat_id = 56,
                chat_member_id = 56,
                added_at = 56,
                attachments = [
                    chat_server_connector.models.chat_message_attachment_read_with_metadata.ChatMessageAttachmentReadWithMetadata(
                        file_id = '', 
                        attachment_type = 'IMAGE', 
                        id = 56, 
                        file_url = '', 
                        full_file_name = '', 
                        file_size = 56, 
                        file_extension = '', 
                        mime_type = '', )
                    ],
                chat_session = chat_server_connector.models.chat_session_get.ChatSessionGet(
                    id = 56, 
                    chat_id = 56, 
                    creator_id = 56, 
                    credentials = chat_server_connector.models.credentials.Credentials(), 
                    chat_session_type = 'TEXT', 
                    created_at = 56, 
                    ended_at = 56, 
                    last_activity_at = 56, ),
                usage = chat_server_connector.models.session_usage.SessionUsage(
                    total_mentorcoin = 1.337, 
                    by_type = [
                        chat_server_connector.models.usage_by_type.UsageByType(
                            type = 'text', 
                            mentorcoin = 1.337, )
                        ], ),
                feedback = chat_server_connector.models.feedback_read.FeedbackRead(
                    id = 56, 
                    chat_session_id = 56, 
                    chat_member_id = 56, 
                    type = 'BUG', 
                    text = '', 
                    priority = 56, 
                    added_at = 56, 
                    updated_at = 56, )
            )
        else:
            return ChatMessageReadWithMetadata(
                id = 56,
                chat_message_type = 'TEXT',
                chat_id = 56,
                chat_member_id = 56,
                added_at = 56,
        )
        """

    def testChatMessageReadWithMetadata(self):
        """Test ChatMessageReadWithMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
